@@ -28,44 +28,55 @@ from .textwrap import DALS
 
 WHEEL_INFO_TESTS = (
     ('invalid.whl', ValueError),
-    ('simplewheel-2.0-1-py2.py3-none-any.whl', {
-        'project_name': 'simplewheel',
-        'version': '2.0',
-        'build': '1',
-        'py_version': 'py2.py3',
-        'abi': 'none',
-        'platform': 'any',
-    }),
-    ('simple.dist-0.1-py2.py3-none-any.whl', {
-        'project_name': 'simple.dist',
-        'version': '0.1',
-        'build': None,
-        'py_version': 'py2.py3',
-        'abi': 'none',
-        'platform': 'any',
-    }),
-    ('example_pkg_a-1-py3-none-any.whl', {
-        'project_name': 'example_pkg_a',
-        'version': '1',
-        'build': None,
-        'py_version': 'py3',
-        'abi': 'none',
-        'platform': 'any',
-    }),
-    ('PyQt5-5.9-5.9.1-cp35.cp36.cp37-abi3-manylinux1_x86_64.whl', {
-        'project_name': 'PyQt5',
-        'version': '5.9',
-        'build': '5.9.1',
-        'py_version': 'cp35.cp36.cp37',
-        'abi': 'abi3',
-        'platform': 'manylinux1_x86_64',
-    }),
+    (
+        'simplewheel-2.0-1-py2.py3-none-any.whl',
+        {
+            'project_name': 'simplewheel',
+            'version': '2.0',
+            'build': '1',
+            'py_version': 'py2.py3',
+            'abi': 'none',
+            'platform': 'any',
+        },
+    ),
+    (
+        'simple.dist-0.1-py2.py3-none-any.whl',
+        {
+            'project_name': 'simple.dist',
+            'version': '0.1',
+            'build': None,
+            'py_version': 'py2.py3',
+            'abi': 'none',
+            'platform': 'any',
+        },
+    ),
+    (
+        'example_pkg_a-1-py3-none-any.whl',
+        {
+            'project_name': 'example_pkg_a',
+            'version': '1',
+            'build': None,
+            'py_version': 'py3',
+            'abi': 'none',
+            'platform': 'any',
+        },
+    ),
+    (
+        'PyQt5-5.9-5.9.1-cp35.cp36.cp37-abi3-manylinux1_x86_64.whl',
+        {
+            'project_name': 'PyQt5',
+            'version': '5.9',
+            'build': '5.9.1',
+            'py_version': 'cp35.cp36.cp37',
+            'abi': 'abi3',
+            'platform': 'manylinux1_x86_64',
+        },
+    ),
 )
 
 
 @pytest.mark.parametrize(
-    ('filename', 'info'), WHEEL_INFO_TESTS,
-    ids=[t[0] for t in WHEEL_INFO_TESTS]
+    ('filename', 'info'), WHEEL_INFO_TESTS, ids=[t[0] for t in WHEEL_INFO_TESTS]
 )
 def test_wheel_info(filename, info):
     if inspect.isclass(info):
@@ -79,21 +90,25 @@ def test_wheel_info(filename, info):
 @contextlib.contextmanager
 def build_wheel(extra_file_defs=None, **kwargs):
     file_defs = {
-        'setup.py': (DALS(
-            '''
+        'setup.py': (
+            DALS(
+                '''
             # -*- coding: utf-8 -*-
             from setuptools import setup
             import setuptools
             setup(**%r)
             '''
-        ) % kwargs).encode('utf-8'),
+            )
+            % kwargs
+        ).encode('utf-8'),
     }
     if extra_file_defs:
         file_defs.update(extra_file_defs)
     with tempdir() as source_dir:
         path.build(file_defs, source_dir)
-        subprocess.check_call((sys.executable, 'setup.py',
-                               '-q', 'bdist_wheel'), cwd=source_dir)
+        subprocess.check_call(
+            (sys.executable, 'setup.py', '-q', 'bdist_wheel'), cwd=source_dir
+        )
         yield glob.glob(os.path.join(source_dir, 'dist', '*.whl'))[0]
 
 
@@ -101,8 +116,7 @@ def tree_set(root):
     contents = set()
     for dirpath, dirnames, filenames in os.walk(root):
         for filename in filenames:
-            contents.add(os.path.join(os.path.relpath(dirpath, root),
-                                      filename))
+            contents.add(os.path.join(os.path.relpath(dirpath, root), filename))
     return contents
 
 
@@ -115,8 +129,7 @@ def flatten_tree(tree):
 
         for elem in contents:
             if isinstance(elem, dict):
-                output |= {os.path.join(node, val)
-                           for val in flatten_tree(elem)}
+                output |= {os.path.join(node, val) for val in flatten_tree(elem)}
             else:
                 output.add(os.path.join(node, elem))
     return output
@@ -127,19 +140,22 @@ def format_install_tree(tree):
         x.format(
             py_version=PY_MAJOR,
             platform=get_platform(),
-            shlib_ext=get_config_var('EXT_SUFFIX') or get_config_var('SO'))
-        for x in tree}
+            shlib_ext=get_config_var('EXT_SUFFIX') or get_config_var('SO'),
+        )
+        for x in tree
+    }
 
 
-def _check_wheel_install(filename, install_dir, install_tree_includes,
-                         project_name, version, requires_txt):
+def _check_wheel_install(
+    filename, install_dir, install_tree_includes, project_name, version, requires_txt
+):
     w = Wheel(filename)
     egg_path = os.path.join(install_dir, w.egg_name())
     w.install_as_egg(egg_path)
     if install_tree_includes is not None:
         install_tree = format_install_tree(install_tree_includes)
         exp = tree_set(install_dir)
-        assert install_tree.issubset(exp), (install_tree - exp)
+        assert install_tree.issubset(exp), install_tree - exp
 
     metadata = PathMetadata(egg_path, os.path.join(egg_path, 'EGG-INFO'))
     dist = Distribution.from_filename(egg_path, metadata=metadata)
@@ -153,7 +169,6 @@ def _check_wheel_install(filename, install_dir, install_tree_includes,
 
 
 class Record:
-
     def __init__(self, id, **kwargs):
         self._id = id
         self._fields = kwargs
@@ -163,37 +178,27 @@ class Record:
 
 
 WHEEL_INSTALL_TESTS = (
-
     dict(
         id='basic',
-        file_defs={
-            'foo': {
-                '__init__.py': ''
-            }
-        },
+        file_defs={'foo': {'__init__.py': ''}},
         setup_kwargs=dict(
             packages=['foo'],
         ),
-        install_tree=flatten_tree({
-            'foo-1.0-py{py_version}.egg': {
-                'EGG-INFO': [
-                    'PKG-INFO',
-                    'RECORD',
-                    'WHEEL',
-                    'top_level.txt'
-                ],
-                'foo': ['__init__.py']
+        install_tree=flatten_tree(
+            {
+                'foo-1.0-py{py_version}.egg': {
+                    'EGG-INFO': ['PKG-INFO', 'RECORD', 'WHEEL', 'top_level.txt'],
+                    'foo': ['__init__.py'],
+                }
             }
-        }),
+        ),
     ),
-
     dict(
         id='utf-8',
         setup_kwargs=dict(
             description='Description accentuée',
-        )
+        ),
     ),
-
     dict(
         id='data',
         file_defs={
@@ -206,21 +211,15 @@ WHEEL_INSTALL_TESTS = (
         setup_kwargs=dict(
             data_files=[('data_dir', ['data.txt'])],
         ),
-        install_tree=flatten_tree({
-            'foo-1.0-py{py_version}.egg': {
-                'EGG-INFO': [
-                    'PKG-INFO',
-                    'RECORD',
-                    'WHEEL',
-                    'top_level.txt'
-                ],
-                'data_dir': [
-                    'data.txt'
-                ]
+        install_tree=flatten_tree(
+            {
+                'foo-1.0-py{py_version}.egg': {
+                    'EGG-INFO': ['PKG-INFO', 'RECORD', 'WHEEL', 'top_level.txt'],
+                    'data_dir': ['data.txt'],
+                }
             }
-        }),
+        ),
     ),
-
     dict(
         id='extension',
         file_defs={
@@ -270,24 +269,27 @@ WHEEL_INSTALL_TESTS = (
         },
         setup_kwargs=dict(
             ext_modules=[
-                Record('setuptools.Extension',
-                       name='extension',
-                       sources=['extension.c'])
+                Record(
+                    'setuptools.Extension', name='extension', sources=['extension.c']
+                )
             ],
         ),
-        install_tree=flatten_tree({
-            'foo-1.0-py{py_version}-{platform}.egg': [
-                'extension{shlib_ext}',
-                {'EGG-INFO': [
-                    'PKG-INFO',
-                    'RECORD',
-                    'WHEEL',
-                    'top_level.txt',
-                ]},
-            ]
-        }),
+        install_tree=flatten_tree(
+            {
+                'foo-1.0-py{py_version}-{platform}.egg': [
+                    'extension{shlib_ext}',
+                    {
+                        'EGG-INFO': [
+                            'PKG-INFO',
+                            'RECORD',
+                            'WHEEL',
+                            'top_level.txt',
+                        ]
+                    },
+                ]
+            }
+        ),
     ),
-
     dict(
         id='header',
         file_defs={
@@ -299,19 +301,22 @@ WHEEL_INSTALL_TESTS = (
         setup_kwargs=dict(
             headers=['header.h'],
         ),
-        install_tree=flatten_tree({
-            'foo-1.0-py{py_version}.egg': [
-                'header.h',
-                {'EGG-INFO': [
-                    'PKG-INFO',
-                    'RECORD',
-                    'WHEEL',
-                    'top_level.txt',
-                ]},
-            ]
-        }),
+        install_tree=flatten_tree(
+            {
+                'foo-1.0-py{py_version}.egg': [
+                    'header.h',
+                    {
+                        'EGG-INFO': [
+                            'PKG-INFO',
+                            'RECORD',
+                            'WHEEL',
+                            'top_level.txt',
+                        ]
+                    },
+                ]
+            }
+        ),
     ),
-
     dict(
         id='script',
         file_defs={
@@ -331,50 +336,49 @@ WHEEL_INSTALL_TESTS = (
         setup_kwargs=dict(
             scripts=['script.py', 'script.sh'],
         ),
-        install_tree=flatten_tree({
-            'foo-1.0-py{py_version}.egg': {
-                'EGG-INFO': [
-                    'PKG-INFO',
-                    'RECORD',
-                    'WHEEL',
-                    'top_level.txt',
-                    {'scripts': [
-                        'script.py',
-                        'script.sh'
-                    ]}
-
-                ]
+        install_tree=flatten_tree(
+            {
+                'foo-1.0-py{py_version}.egg': {
+                    'EGG-INFO': [
+                        'PKG-INFO',
+                        'RECORD',
+                        'WHEEL',
+                        'top_level.txt',
+                        {'scripts': ['script.py', 'script.sh']},
+                    ]
+                }
             }
-        })
+        ),
     ),
-
     dict(
         id='requires1',
         install_requires='foobar==2.0',
-        install_tree=flatten_tree({
-            'foo-1.0-py{py_version}.egg': {
-                'EGG-INFO': [
-                    'PKG-INFO',
-                    'RECORD',
-                    'WHEEL',
-                    'requires.txt',
-                    'top_level.txt',
-                ]
+        install_tree=flatten_tree(
+            {
+                'foo-1.0-py{py_version}.egg': {
+                    'EGG-INFO': [
+                        'PKG-INFO',
+                        'RECORD',
+                        'WHEEL',
+                        'requires.txt',
+                        'top_level.txt',
+                    ]
+                }
             }
-        }),
+        ),
         requires_txt=DALS(
             '''
             foobar==2.0
             '''
         ),
     ),
-
     dict(
         id='requires2',
         install_requires='''
         bar
         foo<=2.0; %r in sys_platform
-        ''' % sys.platform,
+        '''
+        % sys.platform,
         requires_txt=DALS(
             '''
             bar
@@ -382,14 +386,13 @@ WHEEL_INSTALL_TESTS = (
             '''
         ),
     ),
-
     dict(
         id='requires3',
         install_requires='''
         bar; %r != sys_platform
-        ''' % sys.platform,
+        '''
+        % sys.platform,
     ),
-
     dict(
         id='requires4',
         install_requires='''
@@ -407,7 +410,6 @@ WHEEL_INSTALL_TESTS = (
             '''
         ),
     ),
-
     dict(
         id='requires5',
         extras_require={
@@ -419,7 +421,6 @@ WHEEL_INSTALL_TESTS = (
             '''
         ),
     ),
-
     dict(
         id='requires_ensure_order',
         install_requires='''
@@ -451,67 +452,75 @@ WHEEL_INSTALL_TESTS = (
             '''
         ),
     ),
-
     dict(
         id='namespace_package',
         file_defs={
             'foo': {
-                'bar': {
-                    '__init__.py': ''
-                },
+                'bar': {'__init__.py': ''},
             },
         },
         setup_kwargs=dict(
             namespace_packages=['foo'],
             packages=['foo.bar'],
         ),
-        install_tree=flatten_tree({
-            'foo-1.0-py{py_version}.egg': [
-                'foo-1.0-py{py_version}-nspkg.pth',
-                {'EGG-INFO': [
-                    'PKG-INFO',
-                    'RECORD',
-                    'WHEEL',
-                    'namespace_packages.txt',
-                    'top_level.txt',
-                ]},
-                {'foo': [
-                    '__init__.py',
-                    {'bar': ['__init__.py']},
-                ]},
-            ]
-        }),
+        install_tree=flatten_tree(
+            {
+                'foo-1.0-py{py_version}.egg': [
+                    'foo-1.0-py{py_version}-nspkg.pth',
+                    {
+                        'EGG-INFO': [
+                            'PKG-INFO',
+                            'RECORD',
+                            'WHEEL',
+                            'namespace_packages.txt',
+                            'top_level.txt',
+                        ]
+                    },
+                    {
+                        'foo': [
+                            '__init__.py',
+                            {'bar': ['__init__.py']},
+                        ]
+                    },
+                ]
+            }
+        ),
     ),
-
     dict(
         id='empty_namespace_package',
         file_defs={
             'foobar': {
-                '__init__.py':
-                    "__import__('pkg_resources').declare_namespace(__name__)",
+                '__init__.py': (
+                    "__import__('pkg_resources').declare_namespace(__name__)"
+                )
             },
         },
         setup_kwargs=dict(
             namespace_packages=['foobar'],
             packages=['foobar'],
         ),
-        install_tree=flatten_tree({
-            'foo-1.0-py{py_version}.egg': [
-                'foo-1.0-py{py_version}-nspkg.pth',
-                {'EGG-INFO': [
-                    'PKG-INFO',
-                    'RECORD',
-                    'WHEEL',
-                    'namespace_packages.txt',
-                    'top_level.txt',
-                ]},
-                {'foobar': [
-                    '__init__.py',
-                ]},
-            ]
-        }),
+        install_tree=flatten_tree(
+            {
+                'foo-1.0-py{py_version}.egg': [
+                    'foo-1.0-py{py_version}-nspkg.pth',
+                    {
+                        'EGG-INFO': [
+                            'PKG-INFO',
+                            'RECORD',
+                            'WHEEL',
+                            'namespace_packages.txt',
+                            'top_level.txt',
+                        ]
+                    },
+                    {
+                        'foobar': [
+                            '__init__.py',
+                        ]
+                    },
+                ]
+            }
+        ),
     ),
-
     dict(
         id='data_in_package',
         file_defs={
@@ -523,36 +532,40 @@ WHEEL_INSTALL_TESTS = (
                         Some data...
                         '''
                     ),
-                }
+                },
             }
         },
         setup_kwargs=dict(
             packages=['foo'],
             data_files=[('foo/data_dir', ['foo/data_dir/data.txt'])],
         ),
-        install_tree=flatten_tree({
-            'foo-1.0-py{py_version}.egg': {
-                'EGG-INFO': [
-                    'PKG-INFO',
-                    'RECORD',
-                    'WHEEL',
-                    'top_level.txt',
-                ],
-                'foo': [
-                    '__init__.py',
-                    {'data_dir': [
-                        'data.txt',
-                    ]}
-                ]
+        install_tree=flatten_tree(
+            {
+                'foo-1.0-py{py_version}.egg': {
+                    'EGG-INFO': [
+                        'PKG-INFO',
+                        'RECORD',
+                        'WHEEL',
+                        'top_level.txt',
+                    ],
+                    'foo': [
+                        '__init__.py',
+                        {
+                            'data_dir': [
+                                'data.txt',
+                            ]
+                        },
+                    ],
+                }
             }
-        }),
+        ),
     ),
-
 )
 
 
 @pytest.mark.parametrize(
-    'params', WHEEL_INSTALL_TESTS,
+    'params',
+    WHEEL_INSTALL_TESTS,
     ids=list(params['id'] for params in WHEEL_INSTALL_TESTS),
 )
 def test_wheel_install(params):
@@ -572,24 +585,28 @@ def test_wheel_install(params):
         extra_file_defs=file_defs,
         **setup_kwargs
     ) as filename, tempdir() as install_dir:
-        _check_wheel_install(filename, install_dir,
-                             install_tree, project_name,
-                             version, requires_txt)
+        _check_wheel_install(
+            filename, install_dir, install_tree, project_name, version, requires_txt
+        )
 
 
 def test_wheel_install_pep_503():
-    project_name = 'Foo_Bar'    # PEP 503 canonicalized name is "foo-bar"
+    project_name = 'Foo_Bar'  # PEP 503 canonicalized name is "foo-bar"
     version = '1.0'
     with build_wheel(
         name=project_name,
         version=version,
     ) as filename, tempdir() as install_dir:
-        new_filename = filename.replace(project_name,
-                                        canonicalize_name(project_name))
+        new_filename = filename.replace(project_name, canonicalize_name(project_name))
         shutil.move(filename, new_filename)
-        _check_wheel_install(new_filename, install_dir, None,
-                             canonicalize_name(project_name),
-                             version, None)
+        _check_wheel_install(
+            new_filename,
+            install_dir,
+            None,
+            canonicalize_name(project_name),
+            version,
+            None,
+        )
 
 
 def test_wheel_no_dist_dir():
@@ -602,9 +619,9 @@ def test_wheel_no_dist_dir():
         zipfile.ZipFile(wheel_path, 'w').close()
         with tempdir() as install_dir:
             with pytest.raises(ValueError):
-                _check_wheel_install(wheel_path, install_dir, None,
-                                     project_name,
-                                     version, None)
+                _check_wheel_install(
+                    wheel_path, install_dir, None, project_name, version, None
+                )
 
 
 def test_wheel_is_compatible(monkeypatch):
@@ -613,23 +630,26 @@ def test_wheel_is_compatible(monkeypatch):
             (t.interpreter, t.abi, t.platform)
             for t in parse_tag('cp36-cp36m-manylinux1_x86_64')
         }
+
     monkeypatch.setattr('setuptools.wheel._get_supported_tags', sys_tags)
-    assert Wheel(
-        'onnxruntime-0.1.2-cp36-cp36m-manylinux1_x86_64.whl').is_compatible()
+    assert Wheel('onnxruntime-0.1.2-cp36-cp36m-manylinux1_x86_64.whl').is_compatible()
 
 
 def test_wheel_mode():
     @contextlib.contextmanager
     def build_wheel(extra_file_defs=None, **kwargs):
         file_defs = {
-            'setup.py': (DALS(
-                '''
+            'setup.py': (
+                DALS(
+                    '''
                 # -*- coding: utf-8 -*-
                 from setuptools import setup
                 import setuptools
                 setup(**%r)
                 '''
-            ) % kwargs).encode('utf-8'),
+                )
+                % kwargs
+            ).encode('utf-8'),
         }
         if extra_file_defs:
             file_defs.update(extra_file_defs)
@@ -637,8 +657,9 @@ def test_wheel_mode():
             path.build(file_defs, source_dir)
             runsh = pathlib.Path(source_dir) / "script.sh"
             os.chmod(runsh, 0o777)
-            subprocess.check_call((sys.executable, 'setup.py',
-                                   '-q', 'bdist_wheel'), cwd=source_dir)
+            subprocess.check_call(
+                (sys.executable, 'setup.py', '-q', 'bdist_wheel'), cwd=source_dir
+            )
             yield glob.glob(os.path.join(source_dir, 'dist', '*.whl'))[0]
 
     params = dict(
@@ -660,21 +681,19 @@ def test_wheel_mode():
         setup_kwargs=dict(
             scripts=['script.py', 'script.sh'],
         ),
-        install_tree=flatten_tree({
-            'foo-1.0-py{py_version}.egg': {
-                'EGG-INFO': [
-                    'PKG-INFO',
-                    'RECORD',
-                    'WHEEL',
-                    'top_level.txt',
-                    {'scripts': [
-                        'script.py',
-                        'script.sh'
-                    ]}
-
-                ]
+        install_tree=flatten_tree(
+            {
+                'foo-1.0-py{py_version}.egg': {
+                    'EGG-INFO': [
+                        'PKG-INFO',
+                        'RECORD',
+                        'WHEEL',
+                        'top_level.txt',
+                        {'scripts': ['script.py', 'script.sh']},
+                    ]
+                }
             }
-        })
+        ),
     )
 
     project_name = params.get('name', 'foo')
@@ -691,9 +710,9 @@ def test_wheel_mode():
         extra_file_defs=file_defs,
         **setup_kwargs
     ) as filename, tempdir() as install_dir:
-        _check_wheel_install(filename, install_dir,
-                             install_tree, project_name,
-                             version, None)
+        _check_wheel_install(
+            filename, install_dir, install_tree, project_name, version, None
+        )
         w = Wheel(filename)
         base = pathlib.Path(install_dir) / w.egg_name()
         script_sh = base / "EGG-INFO" / "scripts" / "script.sh"
